# Symfony Packages

## INTRODUCTION

The Symfony Packages module provides a comprehensive view of all Symfony packages installed in your Drupal 11 site. It creates a new report page in the administration interface where site administrators can view detailed information about each Symfony package, including version information, update status, and package descriptions.

## REQUIREMENTS

* Drupal 11
* Composer

## INSTALLATION

Install the module as you would normally install a contributed Drupal module. Visit 
https://www.drupal.org/docs/extending-drupal/installing-modules for further information.

## CONFIGURATION

1. Enable the module.
2. Grant the "View installed Symfony packages" permission to appropriate roles.
3. Navigate to Reports > Symfony Packages (/admin/reports/symfony-packages) to view the report.

## FEATURES

* Lists all installed Symfony packages with their current versions
* Shows update status for each package with visual indicators
* Displays the latest available version for each package
* Shows pre-release version information when available (displayed as "Also available" under the latest version)
* Provides package descriptions from Packagist
* Identifies which packages are required by Drupal core versus contributed modules
* Filters packages by name or description
* Compatible with Gin Admin Theme (4.0.x branch)
* Integrates with Drupal's permission system
* Uses Composer commands for accurate package information
* Caches package data for improved performance

## TECHNICAL DETAILS

The module utilizes Composer to gather information about installed Symfony packages and their latest versions. The built-in caching system ensures optimal performance by storing package details for reuse without requiring repeated Composer commands.

The module contains:
- A service for retrieving and processing package information
- A controller that builds the report page
- A filter form for searching through the packages
- CSS styling to enhance the visual presentation of package status
- Integration with Drupal's administrative reports section

The module identifies packages required by Drupal core by examining Drupal's core composer.json file. It also checks for pre-release versions (alpha, beta, RC) of packages and displays them as additional information when a newer version series is available.

## TROUBLESHOOTING

* Ensure your Drupal installation is managed by Composer
* The module requires access to the composer.json and vendor directory
* If package information isn't displaying correctly, try clearing the module's cache using the provided service

## MAINTAINERS

Current maintainers:
* Chris Matthews - https://www.drupal.org/u/chris-matthews
