<?php

declare(strict_types=1);

namespace Drupal\symfony_packages\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\RequestStack;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Filter form for the Symfony packages report.
 */
class SymfonyPackagesFilterForm extends FormBase {

  /**
   * The request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected RequestStack $requestStack;

  /**
   * Constructs a SymfonyPackagesFilterForm object.
   *
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   The request stack.
   */
  public function __construct(RequestStack $request_stack) {
    $this->requestStack = $request_stack;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('request_stack')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'symfony_packages_filter_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $request = $this->requestStack->getCurrentRequest();
    $filter = $request->query->get('filter', '');

    $form['#attributes'] = ['class' => ['symfony-packages-filter-form']];
    $form['#method'] = 'get';

    $form['filter_wrapper'] = [
      '#type' => 'container',
      '#attributes' => [
        'class' => ['container-inline'],
      ],
    ];

    $form['filter_wrapper']['filter'] = [
      '#type' => 'search',
      '#title' => $this->t('Filter packages'),
      '#title_display' => 'invisible',
      '#size' => 30,
      '#default_value' => $filter,
      '#placeholder' => $this->t('Filter by name or description'),
    ];

    $form['filter_wrapper']['actions'] = [
      '#type' => 'actions',
    ];

    $form['filter_wrapper']['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Filter'),
    ];

    if ($filter) {
      $form['filter_wrapper']['actions']['reset'] = [
        '#type' => 'link',
        '#title' => $this->t('Reset'),
        '#url' => Url::fromRoute('symfony_packages.report'),
        '#attributes' => [
          'class' => ['button'],
        ],
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $form_state->setRedirect(
      'symfony_packages.report',
      ['filter' => $form_state->getValue('filter')]
    );
  }

}
