<?php

namespace Drupal\Tests\symfony_packages\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests the Symfony Packages module.
 *
 * @group symfony_packages
 */
class SymfonyPackagesTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'symfony_packages',
  ];

  /**
   * Tests that the Symfony packages report page is accessible.
   */
  public function testReportAccess(): void {
    // Create a user with the required permission.
    $account = $this->drupalCreateUser(['view symfony packages']);
    $this->drupalLogin($account);

    // Access the report page.
    $this->drupalGet('admin/reports/symfony-packages');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('Symfony Packages');

    // Test filter functionality.
    $this->assertSession()->fieldExists('filter');

    // Check for the existence of at least one Symfony package.
    $this->assertSession()->pageTextContains('symfony/');

    // Verify the status indicators are present.
    $this->assertSession()->elementExists('css', '.package-status');

    // Test permission restrictions.
    $this->drupalLogout();
    $this->drupalGet('admin/reports/symfony-packages');
    $this->assertSession()->statusCodeEquals(403);
  }

}
